"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from livepeer_ai import utils
from livepeer_ai._hooks import HookContext
from livepeer_ai.models import components, errors, operations
from livepeer_ai.types import BaseModel, OptionalNullable, UNSET
from typing import Any, Optional, Union, cast


class Generate(BaseSDK):
    def text_to_image(
        self,
        *,
        request: Union[
            components.TextToImageParams, components.TextToImageParamsTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenTextToImageResponse:
        r"""Text To Image

        Generate images from text prompts.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.TextToImageParams)
        request = cast(components.TextToImageParams, request)

        req = self.build_request(
            method="POST",
            path="/text-to-image",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", components.TextToImageParams
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genTextToImage",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenTextToImageResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def text_to_image_async(
        self,
        *,
        request: Union[
            components.TextToImageParams, components.TextToImageParamsTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenTextToImageResponse:
        r"""Text To Image

        Generate images from text prompts.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.TextToImageParams)
        request = cast(components.TextToImageParams, request)

        req = self.build_request_async(
            method="POST",
            path="/text-to-image",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", components.TextToImageParams
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genTextToImage",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenTextToImageResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def image_to_image(
        self,
        *,
        request: Union[
            components.BodyGenImageToImage, components.BodyGenImageToImageTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToImageResponse:
        r"""Image To Image

        Apply image transformations to a provided image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToImage)
        request = cast(components.BodyGenImageToImage, request)

        req = self.build_request(
            method="POST",
            path="/image-to-image",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToImage
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genImageToImage",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToImageResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def image_to_image_async(
        self,
        *,
        request: Union[
            components.BodyGenImageToImage, components.BodyGenImageToImageTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToImageResponse:
        r"""Image To Image

        Apply image transformations to a provided image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToImage)
        request = cast(components.BodyGenImageToImage, request)

        req = self.build_request_async(
            method="POST",
            path="/image-to-image",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToImage
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genImageToImage",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToImageResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def image_to_video(
        self,
        *,
        request: Union[
            components.BodyGenImageToVideo, components.BodyGenImageToVideoTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToVideoResponse:
        r"""Image To Video

        Generate a video from a provided image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToVideo)
        request = cast(components.BodyGenImageToVideo, request)

        req = self.build_request(
            method="POST",
            path="/image-to-video",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToVideo
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genImageToVideo",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToVideoResponse(
                video_response=utils.unmarshal_json(
                    http_res.text, Optional[components.VideoResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def image_to_video_async(
        self,
        *,
        request: Union[
            components.BodyGenImageToVideo, components.BodyGenImageToVideoTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToVideoResponse:
        r"""Image To Video

        Generate a video from a provided image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToVideo)
        request = cast(components.BodyGenImageToVideo, request)

        req = self.build_request_async(
            method="POST",
            path="/image-to-video",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToVideo
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genImageToVideo",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToVideoResponse(
                video_response=utils.unmarshal_json(
                    http_res.text, Optional[components.VideoResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def upscale(
        self,
        *,
        request: Union[components.BodyGenUpscale, components.BodyGenUpscaleTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenUpscaleResponse:
        r"""Upscale

        Upscale an image by increasing its resolution.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenUpscale)
        request = cast(components.BodyGenUpscale, request)

        req = self.build_request(
            method="POST",
            path="/upscale",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenUpscale
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genUpscale",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenUpscaleResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def upscale_async(
        self,
        *,
        request: Union[components.BodyGenUpscale, components.BodyGenUpscaleTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenUpscaleResponse:
        r"""Upscale

        Upscale an image by increasing its resolution.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenUpscale)
        request = cast(components.BodyGenUpscale, request)

        req = self.build_request_async(
            method="POST",
            path="/upscale",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenUpscale
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genUpscale",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenUpscaleResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def audio_to_text(
        self,
        *,
        request: Union[
            components.BodyGenAudioToText, components.BodyGenAudioToTextTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenAudioToTextResponse:
        r"""Audio To Text

        Transcribe audio files to text.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenAudioToText)
        request = cast(components.BodyGenAudioToText, request)

        req = self.build_request(
            method="POST",
            path="/audio-to-text",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenAudioToText
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genAudioToText",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "413", "415", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenAudioToTextResponse(
                text_response=utils.unmarshal_json(
                    http_res.text, Optional[components.TextResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(
            http_res, ["400", "401", "413", "415", "500"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def audio_to_text_async(
        self,
        *,
        request: Union[
            components.BodyGenAudioToText, components.BodyGenAudioToTextTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenAudioToTextResponse:
        r"""Audio To Text

        Transcribe audio files to text.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenAudioToText)
        request = cast(components.BodyGenAudioToText, request)

        req = self.build_request_async(
            method="POST",
            path="/audio-to-text",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenAudioToText
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genAudioToText",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "413", "415", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenAudioToTextResponse(
                text_response=utils.unmarshal_json(
                    http_res.text, Optional[components.TextResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(
            http_res, ["400", "401", "413", "415", "500"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def segment_anything2(
        self,
        *,
        request: Union[
            components.BodyGenSegmentAnything2,
            components.BodyGenSegmentAnything2TypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenSegmentAnything2Response:
        r"""Segment Anything 2

        Segment objects in an image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenSegmentAnything2)
        request = cast(components.BodyGenSegmentAnything2, request)

        req = self.build_request(
            method="POST",
            path="/segment-anything-2",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenSegmentAnything2
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genSegmentAnything2",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenSegmentAnything2Response(
                masks_response=utils.unmarshal_json(
                    http_res.text, Optional[components.MasksResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def segment_anything2_async(
        self,
        *,
        request: Union[
            components.BodyGenSegmentAnything2,
            components.BodyGenSegmentAnything2TypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenSegmentAnything2Response:
        r"""Segment Anything 2

        Segment objects in an image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenSegmentAnything2)
        request = cast(components.BodyGenSegmentAnything2, request)

        req = self.build_request_async(
            method="POST",
            path="/segment-anything-2",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenSegmentAnything2
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genSegmentAnything2",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenSegmentAnything2Response(
                masks_response=utils.unmarshal_json(
                    http_res.text, Optional[components.MasksResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def llm(
        self,
        *,
        request: Union[components.BodyGenLLM, components.BodyGenLLMTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenLLMResponse:
        r"""LLM

        Generate text using a language model.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenLLM)
        request = cast(components.BodyGenLLM, request)

        req = self.build_request(
            method="POST",
            path="/llm",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "form", components.BodyGenLLM
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genLLM",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenLLMResponse(
                llm_response=utils.unmarshal_json(
                    http_res.text, Optional[components.LLMResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def llm_async(
        self,
        *,
        request: Union[components.BodyGenLLM, components.BodyGenLLMTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenLLMResponse:
        r"""LLM

        Generate text using a language model.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenLLM)
        request = cast(components.BodyGenLLM, request)

        req = self.build_request_async(
            method="POST",
            path="/llm",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "form", components.BodyGenLLM
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genLLM",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenLLMResponse(
                llm_response=utils.unmarshal_json(
                    http_res.text, Optional[components.LLMResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, ["400", "401", "500"], "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def image_to_text(
        self,
        *,
        request: Union[
            components.BodyGenImageToText, components.BodyGenImageToTextTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToTextResponse:
        r"""Image To Text

        Transform image files to text.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToText)
        request = cast(components.BodyGenImageToText, request)

        req = self.build_request(
            method="POST",
            path="/image-to-text",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToText
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genImageToText",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "413", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToTextResponse(
                image_to_text_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageToTextResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(
            http_res, ["400", "401", "413", "500"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def image_to_text_async(
        self,
        *,
        request: Union[
            components.BodyGenImageToText, components.BodyGenImageToTextTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToTextResponse:
        r"""Image To Text

        Transform image files to text.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToText)
        request = cast(components.BodyGenImageToText, request)

        req = self.build_request_async(
            method="POST",
            path="/image-to-text",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToText
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genImageToText",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "413", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToTextResponse(
                image_to_text_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageToTextResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(
            http_res, ["400", "401", "413", "500"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, errors.HTTPErrorData)
            raise errors.HTTPError(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, errors.HTTPValidationErrorData)
            raise errors.HTTPValidationError(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class LLMResponseTypedDict(TypedDict):
    response: str
    tokens_used: int


class LLMResponse(BaseModel):
    response: str

    tokens_used: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import io
from livepeer_ai.types import BaseModel
from livepeer_ai.utils import FieldMetadata, MultipartFormMetadata
import pydantic
from typing import IO, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class ImageTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class Image(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="image"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class BodyGenImageToImageTypedDict(TypedDict):
    prompt: str
    r"""Text prompt(s) to guide image generation."""
    image: ImageTypedDict
    r"""Uploaded image to modify with the pipeline."""
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for image generation."""
    loras: NotRequired[str]
    r"""A LoRA (Low-Rank Adaptation) model and its corresponding weight for image generation. Example: { \"latent-consistency/lcm-lora-sdxl\": 1.0, \"nerijs/pixel-art-xl\": 1.2}."""
    strength: NotRequired[float]
    r"""Degree of transformation applied to the reference image (0 to 1)."""
    guidance_scale: NotRequired[float]
    r"""Encourages model to generate images closely linked to the text prompt (higher values may reduce image quality)."""
    image_guidance_scale: NotRequired[float]
    r"""Degree to which the generated image is pushed towards the initial image."""
    negative_prompt: NotRequired[str]
    r"""Text prompt(s) to guide what to exclude from image generation. Ignored if guidance_scale < 1."""
    safety_check: NotRequired[bool]
    r"""Perform a safety check to estimate if generated images could be offensive or harmful."""
    seed: NotRequired[int]
    r"""Seed for random number generation."""
    num_inference_steps: NotRequired[int]
    r"""Number of denoising steps. More steps usually lead to higher quality images but slower inference. Modulated by strength."""
    num_images_per_prompt: NotRequired[int]
    r"""Number of images to generate per prompt."""


class BodyGenImageToImage(BaseModel):
    prompt: Annotated[str, FieldMetadata(multipart=True)]
    r"""Text prompt(s) to guide image generation."""

    image: Annotated[
        Image,
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(file=True)),
    ]
    r"""Uploaded image to modify with the pipeline."""

    model_id: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""Hugging Face model ID used for image generation."""

    loras: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""A LoRA (Low-Rank Adaptation) model and its corresponding weight for image generation. Example: { \"latent-consistency/lcm-lora-sdxl\": 1.0, \"nerijs/pixel-art-xl\": 1.2}."""

    strength: Annotated[Optional[float], FieldMetadata(multipart=True)] = 0.8
    r"""Degree of transformation applied to the reference image (0 to 1)."""

    guidance_scale: Annotated[Optional[float], FieldMetadata(multipart=True)] = 7.5
    r"""Encourages model to generate images closely linked to the text prompt (higher values may reduce image quality)."""

    image_guidance_scale: Annotated[Optional[float], FieldMetadata(multipart=True)] = (
        1.5
    )
    r"""Degree to which the generated image is pushed towards the initial image."""

    negative_prompt: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""Text prompt(s) to guide what to exclude from image generation. Ignored if guidance_scale < 1."""

    safety_check: Annotated[Optional[bool], FieldMetadata(multipart=True)] = True
    r"""Perform a safety check to estimate if generated images could be offensive or harmful."""

    seed: Annotated[Optional[int], FieldMetadata(multipart=True)] = None
    r"""Seed for random number generation."""

    num_inference_steps: Annotated[Optional[int], FieldMetadata(multipart=True)] = 100
    r"""Number of denoising steps. More steps usually lead to higher quality images but slower inference. Modulated by strength."""

    num_images_per_prompt: Annotated[Optional[int], FieldMetadata(multipart=True)] = 1
    r"""Number of images to generate per prompt."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from livepeer_ai.utils import FieldMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BodyGenLLMTypedDict(TypedDict):
    prompt: str
    model_id: NotRequired[str]
    system_msg: NotRequired[str]
    temperature: NotRequired[float]
    max_tokens: NotRequired[int]
    history: NotRequired[str]
    stream: NotRequired[bool]


class BodyGenLLM(BaseModel):
    prompt: Annotated[str, FieldMetadata(form=True)]

    model_id: Annotated[Optional[str], FieldMetadata(form=True)] = ""

    system_msg: Annotated[Optional[str], FieldMetadata(form=True)] = ""

    temperature: Annotated[Optional[float], FieldMetadata(form=True)] = 0.7

    max_tokens: Annotated[Optional[int], FieldMetadata(form=True)] = 256

    history: Annotated[Optional[str], FieldMetadata(form=True)] = "[]"

    stream: Annotated[Optional[bool], FieldMetadata(form=True)] = False



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class ImageToTextResponseTypedDict(TypedDict):
    r"""Response model for text generation."""

    text: str
    r"""The generated text."""


class ImageToTextResponse(BaseModel):
    r"""Response model for text generation."""

    text: str
    r"""The generated text."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import io
from livepeer_ai.types import BaseModel
from livepeer_ai.utils import FieldMetadata, MultipartFormMetadata
import pydantic
from typing import IO, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class BodyGenUpscaleImageTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class BodyGenUpscaleImage(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="image"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class BodyGenUpscaleTypedDict(TypedDict):
    prompt: str
    r"""Text prompt(s) to guide upscaled image generation."""
    image: BodyGenUpscaleImageTypedDict
    r"""Uploaded image to modify with the pipeline."""
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for upscaled image generation."""
    safety_check: NotRequired[bool]
    r"""Perform a safety check to estimate if generated images could be offensive or harmful."""
    seed: NotRequired[int]
    r"""Seed for random number generation."""
    num_inference_steps: NotRequired[int]
    r"""Number of denoising steps. More steps usually lead to higher quality images but slower inference. Modulated by strength."""


class BodyGenUpscale(BaseModel):
    prompt: Annotated[str, FieldMetadata(multipart=True)]
    r"""Text prompt(s) to guide upscaled image generation."""

    image: Annotated[
        BodyGenUpscaleImage,
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(file=True)),
    ]
    r"""Uploaded image to modify with the pipeline."""

    model_id: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""Hugging Face model ID used for upscaled image generation."""

    safety_check: Annotated[Optional[bool], FieldMetadata(multipart=True)] = True
    r"""Perform a safety check to estimate if generated images could be offensive or harmful."""

    seed: Annotated[Optional[int], FieldMetadata(multipart=True)] = None
    r"""Seed for random number generation."""

    num_inference_steps: Annotated[Optional[int], FieldMetadata(multipart=True)] = 75
    r"""Number of denoising steps. More steps usually lead to higher quality images but slower inference. Modulated by strength."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .httperror import HTTPError, HTTPErrorData
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .sdkerror import SDKError

__all__ = [
    "HTTPError",
    "HTTPErrorData",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "SDKError",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import io
from livepeer_ai.types import BaseModel
from livepeer_ai.utils import FieldMetadata, MultipartFormMetadata
import pydantic
from typing import IO, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class BodyGenSegmentAnything2ImageTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class BodyGenSegmentAnything2Image(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="image"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class BodyGenSegmentAnything2TypedDict(TypedDict):
    image: BodyGenSegmentAnything2ImageTypedDict
    r"""Image to segment."""
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for image generation."""
    point_coords: NotRequired[str]
    r"""Nx2 array of point prompts to the model, where each point is in (X,Y) in pixels."""
    point_labels: NotRequired[str]
    r"""Labels for the point prompts, where 1 indicates a foreground point and 0 indicates a background point."""
    box: NotRequired[str]
    r"""A length 4 array given as a box prompt to the model, in XYXY format."""
    mask_input: NotRequired[str]
    r"""A low-resolution mask input to the model, typically from a previous prediction iteration, with the form 1xHxW (H=W=256 for SAM)."""
    multimask_output: NotRequired[bool]
    r"""If true, the model will return three masks for ambiguous input prompts, often producing better masks than a single prediction."""
    return_logits: NotRequired[bool]
    r"""If true, returns un-thresholded mask logits instead of a binary mask."""
    normalize_coords: NotRequired[bool]
    r"""If true, the point coordinates will be normalized to the range [0,1], with point_coords expected to be with respect to image dimensions."""


class BodyGenSegmentAnything2(BaseModel):
    image: Annotated[
        BodyGenSegmentAnything2Image,
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(file=True)),
    ]
    r"""Image to segment."""

    model_id: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""Hugging Face model ID used for image generation."""

    point_coords: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""Nx2 array of point prompts to the model, where each point is in (X,Y) in pixels."""

    point_labels: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""Labels for the point prompts, where 1 indicates a foreground point and 0 indicates a background point."""

    box: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""A length 4 array given as a box prompt to the model, in XYXY format."""

    mask_input: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""A low-resolution mask input to the model, typically from a previous prediction iteration, with the form 1xHxW (H=W=256 for SAM)."""

    multimask_output: Annotated[Optional[bool], FieldMetadata(multipart=True)] = True
    r"""If true, the model will return three masks for ambiguous input prompts, often producing better masks than a single prediction."""

    return_logits: Annotated[Optional[bool], FieldMetadata(multipart=True)] = True
    r"""If true, returns un-thresholded mask logits instead of a binary mask."""

    normalize_coords: Annotated[Optional[bool], FieldMetadata(multipart=True)] = True
    r"""If true, the point coordinates will be normalized to the range [0,1], with point_coords expected to be with respect to image dimensions."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chunk import Chunk, ChunkTypedDict
from livepeer_ai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class TextResponseTypedDict(TypedDict):
    r"""Response model for text generation."""

    text: str
    r"""The generated text."""
    chunks: List[ChunkTypedDict]
    r"""The generated text chunks."""


class TextResponse(BaseModel):
    r"""Response model for text generation."""

    text: str
    r"""The generated text."""

    chunks: List[Chunk]
    r"""The generated text chunks."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .apierror import APIError, APIErrorTypedDict
from .body_genaudiototext import (
    Audio,
    AudioTypedDict,
    BodyGenAudioToText,
    BodyGenAudioToTextTypedDict,
)
from .body_genimagetoimage import (
    BodyGenImageToImage,
    BodyGenImageToImageTypedDict,
    Image,
    ImageTypedDict,
)
from .body_genimagetotext import (
    BodyGenImageToText,
    BodyGenImageToTextImage,
    BodyGenImageToTextImageTypedDict,
    BodyGenImageToTextTypedDict,
)
from .body_genimagetovideo import (
    BodyGenImageToVideo,
    BodyGenImageToVideoImage,
    BodyGenImageToVideoImageTypedDict,
    BodyGenImageToVideoTypedDict,
)
from .body_genllm import BodyGenLLM, BodyGenLLMTypedDict
from .body_gensegmentanything2 import (
    BodyGenSegmentAnything2,
    BodyGenSegmentAnything2Image,
    BodyGenSegmentAnything2ImageTypedDict,
    BodyGenSegmentAnything2TypedDict,
)
from .body_genupscale import (
    BodyGenUpscale,
    BodyGenUpscaleImage,
    BodyGenUpscaleImageTypedDict,
    BodyGenUpscaleTypedDict,
)
from .chunk import Chunk, ChunkTypedDict
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from .imageresponse import ImageResponse, ImageResponseTypedDict
from .imagetotextresponse import ImageToTextResponse, ImageToTextResponseTypedDict
from .llmresponse import LLMResponse, LLMResponseTypedDict
from .masksresponse import MasksResponse, MasksResponseTypedDict
from .media import Media, MediaTypedDict
from .security import Security, SecurityTypedDict
from .textresponse import TextResponse, TextResponseTypedDict
from .texttoimageparams import TextToImageParams, TextToImageParamsTypedDict
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)
from .videoresponse import VideoResponse, VideoResponseTypedDict

__all__ = [
    "APIError",
    "APIErrorTypedDict",
    "Audio",
    "AudioTypedDict",
    "BodyGenAudioToText",
    "BodyGenAudioToTextTypedDict",
    "BodyGenImageToImage",
    "BodyGenImageToImageTypedDict",
    "BodyGenImageToText",
    "BodyGenImageToTextImage",
    "BodyGenImageToTextImageTypedDict",
    "BodyGenImageToTextTypedDict",
    "BodyGenImageToVideo",
    "BodyGenImageToVideoImage",
    "BodyGenImageToVideoImageTypedDict",
    "BodyGenImageToVideoTypedDict",
    "BodyGenLLM",
    "BodyGenLLMTypedDict",
    "BodyGenSegmentAnything2",
    "BodyGenSegmentAnything2Image",
    "BodyGenSegmentAnything2ImageTypedDict",
    "BodyGenSegmentAnything2TypedDict",
    "BodyGenUpscale",
    "BodyGenUpscaleImage",
    "BodyGenUpscaleImageTypedDict",
    "BodyGenUpscaleTypedDict",
    "Chunk",
    "ChunkTypedDict",
    "HTTPMetadata",
    "HTTPMetadataTypedDict",
    "Image",
    "ImageResponse",
    "ImageResponseTypedDict",
    "ImageToTextResponse",
    "ImageToTextResponseTypedDict",
    "ImageTypedDict",
    "LLMResponse",
    "LLMResponseTypedDict",
    "Loc",
    "LocTypedDict",
    "MasksResponse",
    "MasksResponseTypedDict",
    "Media",
    "MediaTypedDict",
    "Security",
    "SecurityTypedDict",
    "TextResponse",
    "TextResponseTypedDict",
    "TextToImageParams",
    "TextToImageParamsTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "VideoResponse",
    "VideoResponseTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai import utils
from livepeer_ai.models.components import apierror as components_apierror
from livepeer_ai.types import BaseModel


class HTTPErrorData(BaseModel):
    detail: components_apierror.APIError
    r"""Detailed error information."""


class HTTPError(Exception):
    r"""HTTP error response model."""

    data: HTTPErrorData

    def __init__(self, data: HTTPErrorData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, HTTPErrorData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TextToImageParamsTypedDict(TypedDict):
    prompt: str
    r"""Text prompt(s) to guide image generation. Separate multiple prompts with '|' if supported by the model."""
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for image generation."""
    loras: NotRequired[str]
    r"""A LoRA (Low-Rank Adaptation) model and its corresponding weight for image generation. Example: { \"latent-consistency/lcm-lora-sdxl\": 1.0, \"nerijs/pixel-art-xl\": 1.2}."""
    height: NotRequired[int]
    r"""The height in pixels of the generated image."""
    width: NotRequired[int]
    r"""The width in pixels of the generated image."""
    guidance_scale: NotRequired[float]
    r"""Encourages model to generate images closely linked to the text prompt (higher values may reduce image quality)."""
    negative_prompt: NotRequired[str]
    r"""Text prompt(s) to guide what to exclude from image generation. Ignored if guidance_scale < 1."""
    safety_check: NotRequired[bool]
    r"""Perform a safety check to estimate if generated images could be offensive or harmful."""
    seed: NotRequired[int]
    r"""Seed for random number generation."""
    num_inference_steps: NotRequired[int]
    r"""Number of denoising steps. More steps usually lead to higher quality images but slower inference. Modulated by strength."""
    num_images_per_prompt: NotRequired[int]
    r"""Number of images to generate per prompt."""


class TextToImageParams(BaseModel):
    prompt: str
    r"""Text prompt(s) to guide image generation. Separate multiple prompts with '|' if supported by the model."""

    model_id: Optional[str] = ""
    r"""Hugging Face model ID used for image generation."""

    loras: Optional[str] = ""
    r"""A LoRA (Low-Rank Adaptation) model and its corresponding weight for image generation. Example: { \"latent-consistency/lcm-lora-sdxl\": 1.0, \"nerijs/pixel-art-xl\": 1.2}."""

    height: Optional[int] = 576
    r"""The height in pixels of the generated image."""

    width: Optional[int] = 1024
    r"""The width in pixels of the generated image."""

    guidance_scale: Optional[float] = 7.5
    r"""Encourages model to generate images closely linked to the text prompt (higher values may reduce image quality)."""

    negative_prompt: Optional[str] = ""
    r"""Text prompt(s) to guide what to exclude from image generation. Ignored if guidance_scale < 1."""

    safety_check: Optional[bool] = True
    r"""Perform a safety check to estimate if generated images could be offensive or harmful."""

    seed: Optional[int] = None
    r"""Seed for random number generation."""

    num_inference_steps: Optional[int] = 50
    r"""Number of denoising steps. More steps usually lead to higher quality images but slower inference. Modulated by strength."""

    num_images_per_prompt: Optional[int] = 1
    r"""Number of images to generate per prompt."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .media import Media, MediaTypedDict
from livepeer_ai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ImageResponseTypedDict(TypedDict):
    r"""Response model for image generation."""

    images: List[MediaTypedDict]
    r"""The generated images."""


class ImageResponse(BaseModel):
    r"""Response model for image generation."""

    images: List[Media]
    r"""The generated images."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class MasksResponseTypedDict(TypedDict):
    r"""Response model for object segmentation."""

    masks: str
    r"""The generated masks."""
    scores: str
    r"""The model's confidence scores for each generated mask."""
    logits: str
    r"""The raw, unnormalized predictions (logits) for the masks."""


class MasksResponse(BaseModel):
    r"""Response model for object segmentation."""

    masks: str
    r"""The generated masks."""

    scores: str
    r"""The model's confidence scores for each generated mask."""

    logits: str
    r"""The raw, unnormalized predictions (logits) for the masks."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.models.components import (
    httpmetadata as components_httpmetadata,
    imageresponse as components_imageresponse,
)
from livepeer_ai.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GenUpscaleResponseTypedDict(TypedDict):
    http_meta: components_httpmetadata.HTTPMetadataTypedDict
    image_response: NotRequired[components_imageresponse.ImageResponseTypedDict]
    r"""Successful Response"""


class GenUpscaleResponse(BaseModel):
    http_meta: Annotated[
        Optional[components_httpmetadata.HTTPMetadata], pydantic.Field(exclude=True)
    ] = None

    image_response: Optional[components_imageresponse.ImageResponse] = None
    r"""Successful Response"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class APIErrorTypedDict(TypedDict):
    r"""API error response model."""

    msg: str
    r"""The error message."""


class APIError(BaseModel):
    r"""API error response model."""

    msg: str
    r"""The error message."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import io
from livepeer_ai.types import BaseModel
from livepeer_ai.utils import FieldMetadata, MultipartFormMetadata
import pydantic
from typing import IO, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class BodyGenImageToTextImageTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class BodyGenImageToTextImage(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="image"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class BodyGenImageToTextTypedDict(TypedDict):
    image: BodyGenImageToTextImageTypedDict
    r"""Uploaded image to transform with the pipeline."""
    prompt: NotRequired[str]
    r"""Text prompt(s) to guide transformation."""
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for transformation."""


class BodyGenImageToText(BaseModel):
    image: Annotated[
        BodyGenImageToTextImage,
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(file=True)),
    ]
    r"""Uploaded image to transform with the pipeline."""

    prompt: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""Text prompt(s) to guide transformation."""

    model_id: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""Hugging Face model ID used for transformation."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class MediaTypedDict(TypedDict):
    r"""A media object containing information about the generated media."""

    url: str
    r"""The URL where the media can be accessed."""
    seed: int
    r"""The seed used to generate the media."""
    nsfw: bool
    r"""Whether the media was flagged as NSFW."""


class Media(BaseModel):
    r"""A media object containing information about the generated media."""

    url: str
    r"""The URL where the media can be accessed."""

    seed: int
    r"""The seed used to generate the media."""

    nsfw: bool
    r"""Whether the media was flagged as NSFW."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import io
from livepeer_ai.types import BaseModel
from livepeer_ai.utils import FieldMetadata, MultipartFormMetadata
import pydantic
from typing import IO, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class BodyGenImageToVideoImageTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class BodyGenImageToVideoImage(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="image"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class BodyGenImageToVideoTypedDict(TypedDict):
    image: BodyGenImageToVideoImageTypedDict
    r"""Uploaded image to generate a video from."""
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for video generation."""
    height: NotRequired[int]
    r"""The height in pixels of the generated video."""
    width: NotRequired[int]
    r"""The width in pixels of the generated video."""
    fps: NotRequired[int]
    r"""The frames per second of the generated video."""
    motion_bucket_id: NotRequired[int]
    r"""Used for conditioning the amount of motion for the generation. The higher the number the more motion will be in the video."""
    noise_aug_strength: NotRequired[float]
    r"""Amount of noise added to the conditioning image. Higher values reduce resemblance to the conditioning image and increase motion."""
    safety_check: NotRequired[bool]
    r"""Perform a safety check to estimate if generated images could be offensive or harmful."""
    seed: NotRequired[int]
    r"""Seed for random number generation."""
    num_inference_steps: NotRequired[int]
    r"""Number of denoising steps. More steps usually lead to higher quality images but slower inference. Modulated by strength."""


class BodyGenImageToVideo(BaseModel):
    image: Annotated[
        BodyGenImageToVideoImage,
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(file=True)),
    ]
    r"""Uploaded image to generate a video from."""

    model_id: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""Hugging Face model ID used for video generation."""

    height: Annotated[Optional[int], FieldMetadata(multipart=True)] = 576
    r"""The height in pixels of the generated video."""

    width: Annotated[Optional[int], FieldMetadata(multipart=True)] = 1024
    r"""The width in pixels of the generated video."""

    fps: Annotated[Optional[int], FieldMetadata(multipart=True)] = 6
    r"""The frames per second of the generated video."""

    motion_bucket_id: Annotated[Optional[int], FieldMetadata(multipart=True)] = 127
    r"""Used for conditioning the amount of motion for the generation. The higher the number the more motion will be in the video."""

    noise_aug_strength: Annotated[Optional[float], FieldMetadata(multipart=True)] = 0.02
    r"""Amount of noise added to the conditioning image. Higher values reduce resemblance to the conditioning image and increase motion."""

    safety_check: Annotated[Optional[bool], FieldMetadata(multipart=True)] = True
    r"""Perform a safety check to estimate if generated images could be offensive or harmful."""

    seed: Annotated[Optional[int], FieldMetadata(multipart=True)] = None
    r"""Seed for random number generation."""

    num_inference_steps: Annotated[Optional[int], FieldMetadata(multipart=True)] = 25
    r"""Number of denoising steps. More steps usually lead to higher quality images but slower inference. Modulated by strength."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .genaudiototext import GenAudioToTextResponse, GenAudioToTextResponseTypedDict
from .genimagetoimage import GenImageToImageResponse, GenImageToImageResponseTypedDict
from .genimagetotext import GenImageToTextResponse, GenImageToTextResponseTypedDict
from .genimagetovideo import GenImageToVideoResponse, GenImageToVideoResponseTypedDict
from .genllm import GenLLMResponse, GenLLMResponseTypedDict
from .gensegmentanything2 import (
    GenSegmentAnything2Response,
    GenSegmentAnything2ResponseTypedDict,
)
from .gentexttoimage import GenTextToImageResponse, GenTextToImageResponseTypedDict
from .genupscale import GenUpscaleResponse, GenUpscaleResponseTypedDict

__all__ = [
    "GenAudioToTextResponse",
    "GenAudioToTextResponseTypedDict",
    "GenImageToImageResponse",
    "GenImageToImageResponseTypedDict",
    "GenImageToTextResponse",
    "GenImageToTextResponseTypedDict",
    "GenImageToVideoResponse",
    "GenImageToVideoResponseTypedDict",
    "GenLLMResponse",
    "GenLLMResponseTypedDict",
    "GenSegmentAnything2Response",
    "GenSegmentAnything2ResponseTypedDict",
    "GenTextToImageResponse",
    "GenTextToImageResponseTypedDict",
    "GenUpscaleResponse",
    "GenUpscaleResponseTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing import Any, List
from typing_extensions import TypedDict


class ChunkTypedDict(TypedDict):
    r"""A chunk of text with a timestamp."""

    timestamp: List[Any]
    r"""The timestamp of the chunk."""
    text: str
    r"""The text of the chunk."""


class Chunk(BaseModel):
    r"""A chunk of text with a timestamp."""

    timestamp: List[Any]
    r"""The timestamp of the chunk."""

    text: str
    r"""The text of the chunk."""
